@@ -28,15 +28,14 @@ sub dump {
     print "get message: ", Dumper($message), "\n";
 }
 
-my %args = (
+my %args_dev = (
     addr  => $local_ip,
     sport => 47808,
     id    => 42,
 );
 
-
 # Subscription definition
-my %args1 = (
+my %args_sub = (
     obj_type                      => 0,
     obj_inst                      => 1,
     issue_confirmed_notifications => FALSE,
@@ -47,11 +46,9 @@ my %args1 = (
     on_response                   => \&dump,
 );
 
-my $mydevice = BACnet::Device->new(%args);
+my $mydevice = BACnet::Device->new(%args_dev);
 
-my ( $new_sub, $error ) = $mydevice->subscribe(%args1);
-
-sleep(5);
+my ( $new_sub, $error ) = $mydevice->subscribe(%args_sub);
 
 $mydevice->unsubscribe( $new_sub, \&dump );
 
